# Coupon User:

Every time a user uses a coupon, he will be added to a list called ```Coupon Users``` in admin.

![coupon-user](https://github.com/Wolfterro/django-simple-coupons/raw/master/docs/images/coupon-user.png)